/* automatically generated by configure */
/* edit configure.ac to change version number */
#define PHP_MAJOR_VERSION 8
#define PHP_MINOR_VERSION 4
#define PHP_RELEASE_VERSION 20
#define PHP_EXTRA_VERSION ""
#define PHP_VERSION "8.4.20"
#define PHP_VERSION_ID 80420
